===================
History and credits
===================

Changelog
=========

The project follows the `Semantic Versioning`_ specification for its
version numbers.  Patch-level increments indicate bug fixes, minor
version increments indicate new functionality and major version
increments indicate backwards incompatible changes.

.. _`Semantic Versioning`: http://semver.org/

.. include:: ../CHANGES.rst


Credits
=======

.. include:: ../AUTHORS.rst


